Contrib-Packages
****************


This section describes all contrib packages.

For ``balderhub-battery``
=========================

.. autoclass:: balderhub.ble.contrib.battery.setup_features.BatteryLevelReader
    :members:

.. autoclass:: balderhub.ble.contrib.battery.setup_features.DeviceActivityFeature
    :members:


For ``balderhub-heart``
=======================

.. autoclass:: balderhub.ble.contrib.heart.setup_features.BpmValueReaderFeature
    :members:

.. autoclass:: balderhub.ble.contrib.heart.setup_features.RRValueReaderFeature
    :members:
